"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeImages = void 0;
const path = require("path");
const mergeImages_1 = require("./mergeImages");
/**
 * Writes images to the specified output path.
 *
 * @returns A function that takes an array of Jimp images and returns a promise that resolves to void.
 */
const writeImages = (
/** The path where the images will be saved. */
outputImagePath, 
/**
 * Whether to combine all images into a single image.
 * @defaultValue true
 */
combinePages = true) => (images) => {
    if (combinePages === true) {
        // @ts-expect-error too smart types
        const outputImagePath0 = outputImagePath;
        return (0, mergeImages_1.mergeImages)(images).write(outputImagePath0);
    }
    const parsedPath = path.parse(outputImagePath);
    const partialName = path.join(parsedPath.dir, parsedPath.name);
    const padMaxLen = images.length.toString().length;
    return Promise.all(images.map((img, idx) => img.write(`${partialName}_${String(idx + 1).padStart(padMaxLen, '0')}.png`))).then(() => undefined);
};
exports.writeImages = writeImages;
//# sourceMappingURL=writeImages.js.map